Struct rustc_lint::middle::ty::CrateAnalysisUnstable
[-] [+]
[src]
pub struct CrateAnalysis<'tcx> {
pub export_map: HashMap<u32, Vec<Export>, DefaultState<FnvHasher>>,
pub exported_items: HashSet<u32, DefaultState<FnvHasher>>,
pub public_items: HashSet<u32, DefaultState<FnvHasher>>,
pub ty_cx: ctxt<'tcx>,
pub reachable: HashSet<u32, DefaultState<FnvHasher>>,
pub name: String,
pub glob_map: Option<HashMap<u32, HashSet<Name, RandomState>, RandomState>>,
}The complete set of all analyses described in this module. This is produced by the driver and fed to trans and later passes.
Fields
export_map | |
exported_items | |
public_items | |
ty_cx | |
reachable | |
name | |
glob_map |